## subliment

Split a string or group a collection of words into a list by matching another list of similar words, to create accurate subtitles from the actual script and inaccurate (generated) subtitles.

Example

```python
from subliment import fix

fix(["this", "is", "a", "good", "thing"], "this must be a good thing")
# ["this", "must be", "a", "good", "thing"]

fix(["this", "must", "be", "a", "good", "thing"], "this is a good thing")
# ["this", "", "is", "a", "good", "thing"]
```
